==> Ethna-2.3.1.tgz: Ethna-2.3.1/class/Plugin/Ethna_Plugin_Cachemanager.php <==
<?php
// vim: foldmethod=marker tabstop=4 shiftwidth=4 autoindent
/**
 *  Ethna_Plugin_Cachemanager.php
 *
 *  @author     Masaki Fujimoto <fujimoto@php.net>
 *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
 *  @package    Ethna
 *  @version    $Id: Ethna_Plugin_Cachemanager.php,v 1.2 2006/07/19 05:22:38 fujimoto Exp $
 */

/**
 *  åޥ͡ץ饰󥯥饹
 *
 *  @author     Masaki Fujimoto <fujimoto@php.net>
 *  @access     public
 *  @package    Ethna
 */
class Ethna_Plugin_Cachemanager
{
    /**#@+  @access private */

    /** @var    string  ߤΥ͡ॹڡ */
    var $namespace = '';

    /** @var    object  Ethna_Backend       backend֥ */
    var $backend;

    /** @var    object  Ethna_Config        ꥪ֥    */
    var $config;

    /**#@-*/

    /**
     *  Ethna_Plugin_Cachemanager饹Υ󥹥ȥ饯
     *
     *  @access public
     */
    function Ethna_Plugin_Cachemanager()
    {
        $this->controller =& Ethna_Controller::getInstance();
        $this->backend =& $this->controller->getBackend();
        $this->config =& $this->controller->getConfig();
    }

    /**
     *  å͡ॹڡ
     *
     *  @access public
     *  @return string  ߤΥå͡ॹڡ
     */
    function getNamespace($namespace)
    {
        return $this->namespace;
    }

    /**
     *  å͡ॹڡꤹ
     *
     *  @access public
     *  @param  string  $namespace  ͡ॹڡ
     */
    function setNamespace($namespace)
    {
        $this->namespace = $namespace;
    }

    /**
     *  åꤵ줿ͤ
     *
     *  åͤꤵƤϥå
     *  ͤȤʤ롣å̵ͤlifetime
     *  ᤮Ƥ硢顼ȯPEAR_Error
     *  ֥ȤͤȤʤ롣
     *
     *  @access public
     *  @param  string  $key        å奭
     *  @param  int     $lifetime   åͭ
     *  @param  string  $namespace  å͡ॹڡ
     *  @return mixed   å
     */
    function get($key, $lifetime = null, $namespace = null)
    {
    }

    /**
     *  åκǽ
     *
     *  @access public
     *  @param  string  $key        å奭
     *  @param  string  $namespace  å͡ॹڡ
     *  @return int     ǽ(unixtime)
     */
    function getLastModified($key, $namespace = null)
    {
    }

    /**
     *  åͤꤹ
     *
     *  @access public
     *  @param  string  $key        å奭
     *  @param  mixed   $value      å
     *  @param  int     $timestamp  åǽ(unixtime)
     *  @param  string  $namespace  å͡ॹڡ
     */
    function set($key, $value, $timestamp = null, $namespace = null)
    {
    }

    /**
     *  ͤå夵Ƥ뤫ɤ
     *
     *  @access public
     *  @param  string  $key        å奭
     *  @param  int     $lifetime   åͭ
     *  @param  string  $namespace  å͡ॹڡ
     */
    function isCached($key, $timestamp = null, $namespace = null)
    {
    }

    /**
     *  å夫ͤ
     *
     *  @access public
     *  @param  string  $key        å奭
     *  @param  string  $namespace  å͡ॹڡ
     */
    function clear($key, $namespace = null)
    {
    }

    /**
     *  åǡå
     *
     *  @access public
     *  @param  string  $key        å奭
     *  @param  int     $timeout    åॢ
     *  @param  string  $namespace  å͡ॹڡ
     *  @return bool    true: false:
     */
    function lock($key, $timeout = 5, $namespace = null)
    {
        return false;
    }

    /**
     *  åǡΥå
     *
     *  @access public
     *  @param  string  $key        å奭
     *  @param  string  $namespace  å͡ॹڡ
     *  @return bool    true: false:
     */
    function unlock($key, $namespace = null)
    {
        return false;
    }

    /**
     * ̥ե饰ΩƤ
     *
     * MySQLʤɤĤλҥ饹ͭ
     * 
     * @access public
     * @param bool $flag ե饰
     */
    function setCompress($flag) {
        return false;
    }
}
?>

==> Ethna-2.3.2.tgz: Ethna-2.3.2/class/Plugin/Ethna_Plugin_Cachemanager.php <==
<?php
// vim: foldmethod=marker tabstop=4 shiftwidth=4 autoindent
/**
 *  Ethna_Plugin_Cachemanager.php
 *
 *  @author     Masaki Fujimoto <fujimoto@php.net>
 *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
 *  @package    Ethna
 *  @version    $Id: Ethna_Plugin_Cachemanager.php 464 2007-07-04 13:29:34Z ichii386 $
 */

/**
 *  åޥ͡ץ饰󥯥饹
 *
 *  @author     Masaki Fujimoto <fujimoto@php.net>
 *  @access     public
 *  @package    Ethna
 */
class Ethna_Plugin_Cachemanager
{
    /**#@+  @access private */

    /** @var    string  ߤΥ͡ॹڡ */
    var $namespace = '';

    /** @var    object  Ethna_Backend       backend֥ */
    var $backend;

    /** @var    object  Ethna_Config        ꥪ֥    */
    var $config;

    /**#@-*/

    /**
     *  Ethna_Plugin_Cachemanager饹Υ󥹥ȥ饯
     *
     *  @access public
     */
    function Ethna_Plugin_Cachemanager(&$controller)
    {
        $this->controller =& $controller;
        $this->backend =& $this->controller->getBackend();
        $this->config =& $this->controller->getConfig();
    }

    /**
     *  å͡ॹڡ
     *
     *  @access public
     *  @return string  ߤΥå͡ॹڡ
     */
    function getNamespace($namespace)
    {
        return $this->namespace;
    }

    /**
     *  å͡ॹڡꤹ
     *
     *  @access public
     *  @param  string  $namespace  ͡ॹڡ
     */
    function setNamespace($namespace)
    {
        $this->namespace = $namespace;
    }

    /**
     *  åꤵ줿ͤ
     *
     *  åͤꤵƤϥå
     *  ͤȤʤ롣å̵ͤlifetime
     *  ᤮Ƥ硢顼ȯPEAR_Error
     *  ֥ȤͤȤʤ롣
     *
     *  @access public
     *  @param  string  $key        å奭
     *  @param  int     $lifetime   åͭ
     *  @param  string  $namespace  å͡ॹڡ
     *  @return mixed   å
     */
    function get($key, $lifetime = null, $namespace = null)
    {
    }

    /**
     *  åκǽ
     *
     *  @access public
     *  @param  string  $key        å奭
     *  @param  string  $namespace  å͡ॹڡ
     *  @return int     ǽ(unixtime)
     */
    function getLastModified($key, $namespace = null)
    {
    }

    /**
     *  åͤꤹ
     *
     *  @access public
     *  @param  string  $key        å奭
     *  @param  mixed   $value      å
     *  @param  int     $timestamp  åǽ(unixtime)
     *  @param  string  $namespace  å͡ॹڡ
     */
    function set($key, $value, $timestamp = null, $namespace = null)
    {
    }

    /**
     *  ͤå夵Ƥ뤫ɤ
     *
     *  @access public
     *  @param  string  $key        å奭
     *  @param  int     $lifetime   åͭ
     *  @param  string  $namespace  å͡ॹڡ
     */
    function isCached($key, $timestamp = null, $namespace = null)
    {
    }

    /**
     *  å夫ͤ
     *
     *  @access public
     *  @param  string  $key        å奭
     *  @param  string  $namespace  å͡ॹڡ
     */
    function clear($key, $namespace = null)
    {
    }

    /**
     *  åǡå
     *
     *  @access public
     *  @param  string  $key        å奭
     *  @param  int     $timeout    åॢ
     *  @param  string  $namespace  å͡ॹڡ
     *  @return bool    true: false:
     */
    function lock($key, $timeout = 5, $namespace = null)
    {
        return false;
    }

    /**
     *  åǡΥå
     *
     *  @access public
     *  @param  string  $key        å奭
     *  @param  string  $namespace  å͡ॹڡ
     *  @return bool    true: false:
     */
    function unlock($key, $namespace = null)
    {
        return false;
    }

    /**
     * ̥ե饰ΩƤ
     *
     * MySQLʤɤĤλҥ饹ͭ
     * 
     * @access public
     * @param bool $flag ե饰
     */
    function setCompress($flag) {
        return false;
    }
}
?>
